@@ -63,18 +63,23 @@ ssize_t BlockFileIO::cacheReadOneBlock( const IORequest &req ) const
 	return len;
     } else
     {
+	if(_cache.dataLen > 0)
+	    clearCache( _cache, _blockSize );
+
 	// cache results of read -- issue reads for full blocks
-	_cache.offset = req.offset;
-	_cache.dataLen = _blockSize;
-	ssize_t result = readOneBlock( _cache );
+	IORequest tmp;
+	tmp.offset = req.offset;
+	tmp.data = _cache.data;
+	tmp.dataLen = _blockSize;
+	ssize_t result = readOneBlock( tmp );
 	if(result > 0)
 	{
+	    _cache.offset = req.offset;
 	    _cache.dataLen = result; // the amount we really have
 	    if(result > req.dataLen)
 		result = req.dataLen; // only as much as requested
 	    memcpy( req.data, _cache.data, result );
-	} else
-	    clearCache( _cache, _blockSize );
+	}
 	return result;
     }
 }
