@@ -27,7 +27,9 @@
 #include <stdlib.h>
 #include <pthread.h>
 #include <unistd.h>
+#ifdef linux
 #include <sys/fsuid.h>
+#endif
 
 #include "Cipher.h"
 #include "Mutex.h"
@@ -188,25 +190,13 @@ DirTraverse::~DirTraverse()
 static
 bool _nextName(struct dirent *&de, DIR *dir, int *fileType, ino_t *inode)
 {
-    while((de = ::readdir( dir )) != NULL)
-    {
-	if( de->d_name[0] == '.' )
-	{
-	    if(de->d_name[1] == '\0'
-		    || (de->d_name[1] == '.' && de->d_name[2] == '\0'))
-	    {
-		break; // allow "." and ".." through
-	    }
-	    // skip other dot files - not possible encrypted names
-	} else
-	    break; // let everything else through
-    }
+    de = ::readdir( dir );
 
     if(de)
     {
 	if(fileType)
 	{
-#if defined(_DIRENT_HAVE_D_TYPE)
+#if defined(_DIRENT_HAVE_D_TYPE) || defined(__FreeBSD__)
 	    *fileType = de->d_type;
 #else
 #warning "struct dirent.d_type not supported"
@@ -451,14 +441,31 @@ bool DirNode::genRenameList( list<RenameEl> &renameList, const char *fromP,
     struct dirent *de = NULL;
     while((de = ::readdir( dir )) != NULL)
     {
-	if(de->d_name[0] == '.')
-	    continue; // skip dot files..
+	// decode the name using the oldIV
+	uint64_t localIV = fromIV;
+	string plainName;
+
+	if((de->d_name[0] == '.') &&
+		((de->d_name[1] == '\0') 
+		 || ((de->d_name[1] == '.') && (de->d_name[2] == '\0'))))
+	{
+	    // skip "." and ".."
+	    continue;
+	}
 
 	try
 	{
-	    // decode the name using the oldIV, and re-encode using the new IV..
-	    uint64_t localIV = fromIV;
-	    string plainName = naming->decodePath( de->d_name, &localIV );
+	    plainName = naming->decodePath( de->d_name, &localIV );
+	} catch( rlog::Error &ex )
+	{
+	    // if filename can't be decoded, then ignore it..
+	    continue;
+	}
+
+	// any error in the following will trigger a rename failure.
+	try
+	{
+	    // re-encode using the new IV..
 	    localIV = toIV;
 	    string newName = naming->encodePath( plainName.c_str(), &localIV );
 	
