@@ -24,11 +24,14 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <unistd.h>
+#ifdef linux
 #include <sys/fsuid.h>
+#endif
 
 #include "config.h"
 
 #include "FileNode.h"
+#include "FileUtils.h"
 #include "Cipher.h"
 #include "CipherFileIO.h"
 #include "RawFileIO.h"
@@ -145,6 +148,11 @@ const char *FileNode::plaintextName() const
     return _pname.c_str();
 }
 
+string FileNode::plaintextParent() const
+{
+    return parentDirectory( _pname );
+}
+
 static bool setIV(const Ptr<FileIO> &io, uint64_t iv)
 {
     struct stat stbuf;
@@ -216,7 +224,19 @@ int FileNode::mknod(mode_t mode, dev_t rdev, uid_t uid, gid_t gid)
     if(gid != 0)
 	oldgid = setfsgid( gid );
 
-    res = ::mknod( _cname.c_str(), mode, rdev );
+    /*
+     * cf. xmp_mknod() in fusexmp.c
+     * The regular file stuff could be stripped off if there
+     * were a create method (advised to have)
+     */
+    if (S_ISREG( mode )) {
+        res = ::open( _cname.c_str(), O_CREAT | O_EXCL | O_WRONLY, mode );
+        if (res >= 0)
+            res = ::close( res );
+    } else if (S_ISFIFO( mode ))
+        res = ::mkfifo( _cname.c_str(), mode );
+    else
+        res = ::mknod( _cname.c_str(), mode, rdev );
 
     if(olduid >= 0)
 	setfsuid( olduid );
