@@ -50,6 +50,9 @@ public:
     const char *plaintextName() const;
     const char *cipherName() const;
 
+    // directory portion of plaintextName
+    std::string plaintextParent() const;
+
     // if setIVFirst is true, then the IV is changed before the name is changed
     // (default).  The reverse is also supported for special cases..
     bool setName( const char *plaintextName, const char *cipherName,
