@@ -16,7 +16,9 @@
  */
 
 // defines needed for RedHat 7.3...
+#ifdef linux
 #define _XOPEN_SOURCE 500 // make sure pwrite() is pulled in
+#endif
 #define _BSD_SOURCE // pick up setenv on RH7.3
 
 #include "encfs.h"
@@ -140,6 +142,15 @@ const char *lastPathElement( const char *name )
     return loc ? loc + 1 : name;
 }
 
+std::string parentDirectory( const std::string &path )
+{
+    size_t last = path.find_last_of( '/' );
+    if(last == string::npos)
+	return string("");
+    else
+	return path.substr(0, last);
+}
+
 bool userAllowMkdir( const char *path, mode_t mode )
 {
     // TODO: can we internationalize the y/n names?  Seems strange to prompt in
