@@ -20,6 +20,17 @@
 #include "Cipher.h"
 #include "base64.h"
 
+using namespace rel;
+
+static Ptr<NameIO> NewNNIO( const Interface &, 
+	const Ptr<Cipher> &, const CipherKey & )
+{
+    return Ptr<NameIO>( new NullNameIO() );
+}
+
+static Interface NNIOIface("nameio/null", 1, 0, 0);
+static bool NullNameIO_registered = NameIO::Register("Null",
+	"No encryption of filenames", NNIOIface, NewNNIO);
 
 NullNameIO::NullNameIO( )
 {
@@ -30,6 +41,11 @@ NullNameIO::~NullNameIO()
 {
 }
 
+Interface NullNameIO::interface() const
+{
+    return NNIOIface;
+}
+
 int NullNameIO::maxEncodedNameLen( int plaintextNameLen ) const
 {
     return plaintextNameLen;
@@ -41,7 +57,7 @@ int NullNameIO::maxDecodedNameLen( int encodedNameLen ) const
 }
 
 int NullNameIO::encodeName( const char *plaintextName, int length,
-	char *encodedName ) const
+	uint64_t *iv, char *encodedName ) const
 {
     memcpy( encodedName, plaintextName, length );
 
@@ -49,12 +65,15 @@ int NullNameIO::encodeName( const char *plaintextName, int length,
 }
 
 int NullNameIO::decodeName( const char *encodedName, int length,
-	char *plaintextName ) const
+	uint64_t *iv, char *plaintextName ) const
 {
     memcpy( plaintextName, encodedName, length );
 
     return length;
 }
 
-
+bool NullNameIO::Enabled()
+{
+    return true;
+}
 
