@@ -22,11 +22,16 @@
 
 #include <rlog/rlog.h>
 
-#if defined(HAVE_ATOMIC_GCC) || defined(HAVE_ATOMIC_GCC_PRIVATE)
+#if defined(HAVE_BITS_ATOMICITY_H)
 #include <bits/atomicity.h>
 #define HAVE_ATOMIC_FUNCS
 #endif
 
+#if defined(HAVE_EXT_ATOMICITY_H)
+#include <ext/atomicity.h>
+#define HAVE_ATOMIC_FUNCS
+#endif
+
 #if defined(HAVE_ATOMIC_GCC_PRIVATE)
 using namespace __gnu_cxx;
 #endif
