@@ -15,7 +15,9 @@
  * details.
  */
 
+#ifdef linux
 #define _XOPEN_SOURCE 500 // pick up pread , pwrite
+#endif
 #include <unistd.h>
 
 #include "RawFileIO.h"
@@ -290,7 +292,9 @@ int RawFileIO::truncate( off_t size )
     if(fd >= 0 && canWrite)
     {
 	res = ::ftruncate( fd, size );
+#ifndef __FreeBSD__
 	::fdatasync( fd );
+#endif
     } else
 	res = ::truncate( name.c_str(), size );
 
