@@ -23,10 +23,12 @@
 #include <fcntl.h>
 #include <dirent.h>
 #include <errno.h>
-#include <sys/statfs.h>
+#include <sys/statvfs.h>
 
 #include <sys/types.h>
+#ifdef linux
 #include <sys/fsuid.h>
+#endif
 
 #ifdef HAVE_ATTR_XATTR_H
 #include <attr/xattr.h>
@@ -133,8 +135,8 @@ int encfs_mknod(const char *path, mode_t mode, dev_t rdev)
     {
 	Ptr<FileNode> fnode = FSRoot->lookupNode( path, "mknod" );
 
-	rLog(Info, "mknod on %s, mode %i, dev %" PRIi64, 
-		fnode->cipherName(), mode, rdev);
+	rLog(Info, "mknod on %s, mode %i, dev %" PRIi64,
+		fnode->cipherName(), mode, (int64_t)rdev);
 
 	uid_t uid = 0;
 	gid_t gid = 0;
@@ -145,6 +147,18 @@ int encfs_mknod(const char *path, mode_t mode, dev_t rdev)
 	    gid = context->gid;
 	}
 	res = fnode->mknod( mode, rdev, uid, gid );
+	// Is this error due to access problems?
+	if(gPublicFilesystem && -res == EACCES)
+	{
+	    // try again using the parent dir's group
+	    string parent = fnode->plaintextParent();
+	    rInfo("trying public filesystem workaround for %s", parent.c_str());
+	    Ptr<FileNode> dnode = FSRoot->lookupNode( parent.c_str(), "mknod" );
+
+	    struct stat st;
+	    if(dnode->getAttr( &st ) == 0)
+		res = fnode->mknod( mode, rdev, uid, st.st_gid );
+	}
     } catch( rlog::Error &err )
     {
 	rError("error caught in mknod");
@@ -167,6 +181,17 @@ int encfs_mkdir(const char *path, mode_t mode)
 	    gid = context->gid;
 	}
 	res = FSRoot->mkdir( path, mode, uid, gid );
+	// Is this error due to access problems?
+	if(gPublicFilesystem && -res == EACCES)
+	{
+	    // try again using the parent dir's group
+	    string parent = parentDirectory( path );
+	    Ptr<FileNode> dnode = FSRoot->lookupNode( parent.c_str(), "mkdir" );
+
+	    struct stat st;
+	    if(dnode->getAttr( &st ) == 0)
+		res = FSRoot->mkdir( path, mode, uid, st.st_gid );
+	}
     } catch( rlog::Error &err )
     {
 	rError("error caught in mkdir");
@@ -498,13 +523,21 @@ int encfs_fsync(const char *path, int dataSync,
 	struct fuse_file_info *file)
 {
     (void)path;
+#ifndef linux
+    (void)dataSync;
+#endif
+
     int res = -EIO;
     try
     {
+#ifdef linux
 	if(dataSync == 0)
+#endif
 	    res = fsync( file->fh );
+#ifdef linux
 	else
 	    res = fdatasync( file->fh );
+#endif
 	if(res == -1)
 	    res = -errno;
     } catch( rlog::Error &err )
@@ -539,7 +572,7 @@ int encfs_write(const char *path, const char *buf, size_t size,
     return res;
 }
 
-int encfs_statfs(const char *path, struct statfs *st)
+int encfs_statfs(const char *path, struct statvfs *st)
 {
     int res = -EIO;
     try
@@ -549,11 +582,11 @@ int encfs_statfs(const char *path, struct statfs *st)
 	string cyName = FSRoot->rootDirectory();
 
 	rLog(Info, "doing statfs of %s", cyName.c_str());
-	res = statfs( cyName.c_str(), st );
+	res = statvfs( cyName.c_str(), st );
 	if(!res) 
 	{
 	    // adjust maximum name length..
-	    st->f_namelen     = 6 * (st->f_namelen - 2) / 8; // approx..
+	    st->f_namemax     = 6 * (st->f_namemax - 2) / 8; // approx..
 	}
 	if(res == -1)
 	    res = -errno;
