@@ -34,6 +34,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifdef __FreeBSD__
+#include <libintl.h>
+#endif
 
 #include "i18n.h"
 
@@ -656,7 +659,7 @@ int main(int argc, char **argv)
     slog->subscribeTo( GetGlobalChannel("error") );
     slog->subscribeTo( GetGlobalChannel("warning") );
 #ifndef NO_DEBUG
-    slog->subscribeTo( GetGlobalChannel("debug") );
+    //slog->subscribeTo( GetGlobalChannel("debug") );
 #endif
 
     if(argc < 2)
