@@ -546,6 +546,12 @@ void *encfs_init()
 	}
     }
 
+    if(oldStderr >= 0)
+    {
+	close(oldStderr);
+	oldStderr = -1;
+    }
+
     return (void*)ctx;
 }
  
@@ -669,12 +675,16 @@ int main(int argc, char *argv[])
     encfs_oper.listxattr = encfs_listxattr;
     encfs_oper.removexattr = encfs_removexattr;
 #endif // HAVE_XATTR
-#if FUSE_MINOR_VERSION >= 3 || FUSE_MAJOR_VERSION > 2
-    // .init and .destroy added in fuse 2.3
-    // encfs requires fuse 2.2 at a minimum..
+    //encfs_oper.opendir = encfs_opendir;
+    //encfs_oper.readdir = encfs_readdir;
+    //encfs_oper.releasedir = encfs_releasedir;
+    //encfs_oper.fsyncdir = encfs_fsyncdir;
     encfs_oper.init = encfs_init;
     encfs_oper.destroy = encfs_destroy;
-#endif
+    //encfs_oper.access = encfs_access;
+    //encfs_oper.create = encfs_create;
+    //encfs_oper.ftruncate = encfs_ftruncate;
+    //encfs_oper.fgetattr = encfs_fgetattr;
 
     gPublicFilesystem = encfsArgs->opts.ownerCreate;
     RootPtr rootInfo = initFS( &encfsArgs->opts );
@@ -735,7 +745,7 @@ int main(int argc, char *argv[])
 	    if(res == 0)
 		returnCode = EXIT_SUCCESS;
 
-	    if(res != 0 && encfsArgs->isDaemon
+	    if(res != 0 && encfsArgs->isDaemon && (oldStderr >= 0)
 		    && (endTime - startTime <= 1) )
 	    {
 		// the users will not have seen any message from fuse, so say a
